==> developer-center-api-3.2.14-20181024.092113-1-sources.jar: cn/com/duiba/developer/center/api/domain/dto/visualeditor/VisualEditorAppSkinUnitDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.visualeditor;
import java.io.Serializable;
import java.util.Date;

/**
*
*  @author author
*/
public class VisualEditorAppSkinUnitDto implements Serializable {


    private static final long serialVersionUID = 877594117069101025L;
    /**
    * 主键
    * 物理主键
    * isNullAble:0
    */
    private Long id;

    /**
    * 皮肤id,来源tb_app_skin.id
    * isNullAble:0,defaultVal:0
    */
    private Long skinId;

    /**
    * 组件id,来源tb_skin_unit.id
    * isNullAble:0,defaultVal:0
    */
    private Long unitId;

    /**
     * 前端对于组件的唯一标识
     */
    private String unitKey;

    /**
    * 删除标志位(0-正常 1-删除)
    * isNullAble:0,defaultVal:0
    */
    private Integer deleted;

    /**
    * 组件内容数据
    * isNullAble:1
    */
    private String dataJson;

    /**
    * 创建时间
    * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
    */
    private java.time.LocalDateTime gmtCreate;

    /**
    * 修改时间
    * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
    */
    private Date gmtModified;


    public void setId(Long id){this.id = id;}

    public Long getId(){return this.id;}

    public void setSkinId(Long skinId){this.skinId = skinId;}

    public Long getSkinId(){return this.skinId;}

    public void setUnitId(Long unitId){this.unitId = unitId;}

    public Long getUnitId(){return this.unitId;}

    public String getUnitKey() {
        return unitKey;
    }

    public void setUnitKey(String unitKey) {
        this.unitKey = unitKey;
    }

    public void setDeleted(Integer deleted){this.deleted = deleted;}

    public Integer getDeleted(){return this.deleted;}

    public void setDataJson(String dataJson){this.dataJson = dataJson;}

    public String getDataJson(){return this.dataJson;}

    public void setGmtCreate(java.time.LocalDateTime gmtCreate){this.gmtCreate = gmtCreate;}

    public java.time.LocalDateTime getGmtCreate(){return this.gmtCreate;}

    public void setGmtModified(Date gmtModified){this.gmtModified = gmtModified;}

    public Date getGmtModified(){return this.gmtModified;}
    @Override
    public String toString() {
        return "VisualEditorAppSkinUnit{" +
                "id='" + id + '\'' +
                "skinId='" + skinId + '\'' +
                "unitId='" + unitId + '\'' +
                "deleted='" + deleted + '\'' +
                "dataJson='" + dataJson + '\'' +
                "gmtCreate='" + gmtCreate + '\'' +
                "gmtModified='" + gmtModified + '\'' +
            '}';
    }

}

==> developer-center-api-3.5.59-sources.jar: cn/com/duiba/developer/center/api/domain/dto/visualeditor/VisualEditorAppSkinUnitDto.java <==
package cn.com.duiba.developer.center.api.domain.dto.visualeditor;
import org.apache.commons.lang.builder.ReflectionToStringBuilder;

import java.io.Serializable;
import java.util.Date;

/**
*
*  @author author
*/
public class VisualEditorAppSkinUnitDto implements Serializable {


    private static final long serialVersionUID = 877594117069101025L;
    /**
    * 主键
    * 物理主键
    * isNullAble:0
    */
    private Long id;

    /**
    * 皮肤id,来源tb_app_skin.id
    * isNullAble:0,defaultVal:0
    */
    private Long skinId;

    /**
    * 组件id,来源tb_skin_unit.id
    * isNullAble:0,defaultVal:0
    */
    private Long unitId;

    /**
     * 前端对于组件的唯一标识
     */
    private String unitKey;

    /**
    * 删除标志位(0-正常 1-删除)
    * isNullAble:0,defaultVal:0
    */
    private Integer deleted;

    /**
    * 组件内容数据
    * isNullAble:1
    */
    private String dataJson;

    /**
    * 创建时间
    * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
    */
    private java.time.LocalDateTime gmtCreate;

    /**
    * 修改时间
    * isNullAble:0,defaultVal:CURRENT_TIMESTAMP
    */
    private Date gmtModified;


    public void setId(Long id){this.id = id;}

    public Long getId(){return this.id;}

    public void setSkinId(Long skinId){this.skinId = skinId;}

    public Long getSkinId(){return this.skinId;}

    public void setUnitId(Long unitId){this.unitId = unitId;}

    public Long getUnitId(){return this.unitId;}

    public String getUnitKey() {
        return unitKey;
    }

    public void setUnitKey(String unitKey) {
        this.unitKey = unitKey;
    }

    public void setDeleted(Integer deleted){this.deleted = deleted;}

    public Integer getDeleted(){return this.deleted;}

    public void setDataJson(String dataJson){this.dataJson = dataJson;}

    public String getDataJson(){return this.dataJson;}

    public void setGmtCreate(java.time.LocalDateTime gmtCreate){this.gmtCreate = gmtCreate;}

    public java.time.LocalDateTime getGmtCreate(){return this.gmtCreate;}

    public void setGmtModified(Date gmtModified){this.gmtModified = gmtModified;}

    public Date getGmtModified(){return this.gmtModified;}
    @Override
    public String toString() {
        return ReflectionToStringBuilder.toString(this);
    }

}
